@@ -23,8 +23,16 @@ Date: 05/31/2023
 Version: 0.1.2
 """
 import os
-import platform
-from .read_write_utils import read_from_file
+from .read_write_utils import read_from_file,write_to_file
+from .string_clean import eatAll
+from .list_utils import make_list
+from .type_utils import get_media_exts, is_media_type,MIME_TYPES
+def get_caller_path(i=1):
+    frame = inspect.stack()[i]
+    return os.path.abspath(frame.filename)
+def get_caller_dir(i=1):
+    abspath = get_caller_path(i+1)
+    return os.path.dirname(abspath)
 def get_os_info():
     """
     Get Operating System Information
@@ -572,8 +580,48 @@ def remove_path(path=None):
             remove_directory(path)
         else:
             os.remove(path)
+def get_safe_dirname(path=None):
+    if path:
+        path_str = str(path)
+        return os.path.dirname(path_str)
+def get_safe_basename(path=None):
+    if path:
+        path_str = str(path)
+        return os.path.basename(path_str)
+def get_safe_splitext(path=None,basename=None):
+    basename = basename or get_safe_basename(path=path)
+    if basename:
+        basename_str = str(basename)
+        filename,ext = os.path.splitext(basename_str)
+        return filename,ext
+def get_safe_filename(path=None,basename=None):
+    filename,_ = get_safe_splitext(path=path,basename=basename)
+    return filename
+def get_safe_ext(path=None,basename=None):
+    _,ext = get_safe_splitext(path=path,basename=basename)
+    return ext
+
 def get_file_parts(path):
-    dirName = os.path.dirname(path)
-    baseName = os.path.basename(path)
-    fileName, ext = os.path.splitext(baseName)
-    return {"dirName": dirName, "baseName": baseName, "fileName": fileName, "ext": ext}
+    
+    basename = get_safe_basename(path)
+    filename, ext = get_safe_splitext(basename=basename)
+
+    dirname = get_safe_dirname(path)
+    dirbase = get_safe_basename(dirname)
+    
+    parent_dirname = get_safe_dirname(dirname)
+    parent_dirbase = get_safe_basename(parent_dirname)
+    
+    super_dirname = get_safe_dirname(parent_dirname)
+    super_dirbase = get_safe_basename(super_dirname)
+
+    return {"dirname": dirname,
+            "basename": basename,
+            "filename": filename,
+            "ext": ext,
+            "dirbase":dirbase,
+            "parent_dirname":parent_dirname,
+            "parent_dirbase":parent_dirbase,
+            "super_dirname":super_dirname,
+            "super_dirbase":super_dirbase
+            }
